==> ynab-sdk-0.0.1.tar.gz: ynab-sdk-0.0.1/test/support/fixtures/categories.py <==
VALID_CATEGORIES = {
    "data": {
        "category_groups": [
            {
                "id": "string",
                "name": "string",
                "hidden": True,
                "deleted": True,
                "categories": [
                    {
                        "id": "string",
                        "category_group_id": "string",
                        "name": "string",
                        "hidden": True,
                        "original_category_group_id": "string",
                        "note": "string",
                        "budgeted": 0,
                        "activity": 0,
                        "balance": 0,
                        "goal_type": "TB",
                        "goal_creation_month": "string",
                        "goal_target": 0,
                        "goal_target_month": "string",
                        "goal_percentage_complete": 0,
                        "deleted": True
                    }
                ]
            }
        ],
        "server_knowledge": 0
    }
}

VALID_CATEGORY = {
    "data": {
        "category": {
            "id": "string",
            "category_group_id": "string",
            "name": "string",
            "hidden": True,
            "original_category_group_id": "string",
            "note": "string",
            "budgeted": 0,
            "activity": 0,
            "balance": 0,
            "goal_type": "TB",
            "goal_creation_month": "string",
            "goal_target": 0,
            "goal_target_month": "string",
            "goal_percentage_complete": 0,
            "deleted": True
        }
    }
}

==> ynab-sdk-0.2.4.tar.gz: ynab-sdk-0.2.4/test/support/fixtures/categories.py <==
VALID_CATEGORIES = {
    "data": {
        "category_groups": [
            {
                "id": "string",
                "name": "string",
                "hidden": True,
                "deleted": True,
                "categories": [
                    {
                        "id": "string",
                        "category_group_id": "string",
                        "name": "string",
                        "hidden": True,
                        "original_category_group_id": "string",
                        "note": "string",
                        "budgeted": 0,
                        "activity": 0,
                        "balance": 0,
                        "goal_type": "TB",
                        "goal_creation_month": "string",
                        "goal_target": 0,
                        "goal_target_month": "string",
                        "goal_percentage_complete": 0,
                        "deleted": True,
                    }
                ],
            }
        ],
        "server_knowledge": 0,
    }
}

VALID_CATEGORY = {
    "data": {
        "category": {
            "id": "string",
            "category_group_id": "string",
            "name": "string",
            "hidden": True,
            "original_category_group_id": "string",
            "note": "string",
            "budgeted": 0,
            "activity": 0,
            "balance": 0,
            "goal_type": "TB",
            "goal_creation_month": "string",
            "goal_target": 0,
            "goal_target_month": "string",
            "goal_percentage_complete": 0,
            "deleted": True,
        }
    }
}
